NAME
Math::BigInt::LTM - Use the libtommath library for Math::BigInt routines
SYNOPSIS
use Math::BigInt lib => 'LTM';
## See Math::BigInt docs for usage.
DESCRIPTION
Provides big integer calculations using the libtommath C library.
Since: CryptX-0.029
METHODS
api_version
Returns the backend API version expected by Math::BigInt.
This method exists for Math::BigInt backend integration; normal application code should not need to call it directly.